@@ -49,8 +49,8 @@ def speed_audit(
     session_data = {
         "aws_account_id": aws_account_id,
         "s3_role": "axon_speed_audit",
-        "auth_client_id": "axon_speed_audit",
-        "auth_client_secret": "axon_speed_audit",
+        "auth_client_id": "axon-speed-audit",
+        "auth_client_secret": "axon-speed-audit",
     }
     s3_directory = pathlib.PurePosixPath("test/axon/speed-audit")
     name = "speed-audit-{size}{suffix}.tmp"
