@@ -171,6 +171,11 @@ def djsciops(args: list = None):
                     aws_account_id=djsciops_config["aws"]["account_id"],
                     s3_role=djsciops_config["s3"]["role"],
                     auth_client_id=djsciops_config["djauth"]["client_id"],
+                    **(
+                        {"auth_client_secret": c["client_secret"]}
+                        if "client_secret" in (c := djsciops_config["djauth"])
+                        else {}
+                    ),
                 ),
                 s3_bucket=djsciops_config["s3"]["bucket"],
                 source=kwargs["source"],
@@ -185,6 +190,11 @@ def djsciops(args: list = None):
                     aws_account_id=djsciops_config["aws"]["account_id"],
                     s3_role=djsciops_config["s3"]["role"],
                     auth_client_id=djsciops_config["djauth"]["client_id"],
+                    **(
+                        {"auth_client_secret": c["client_secret"]}
+                        if "client_secret" in (c := djsciops_config["djauth"])
+                        else {}
+                    ),
                 ),
                 s3_bucket=djsciops_config["s3"]["bucket"],
                 source=kwargs["source"],
